@@ -1,7 +1,5 @@
 /*
- * This file is part of bino, a 3D video player.
- *
- * Copyright (C) 2006-2011
+ * Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -51,7 +49,7 @@ exc::exc(const std::string &what, int sys_errno) throw ()
     }
     if (!empty())
     {
-        msg::dbg(_("Exception: %s"), _str.c_str());
+        msg::dbg_txt(_("Exception: %s"), _str.c_str());
     }
 }
 
@@ -69,7 +67,7 @@ exc::exc(int sys_errno) throw ()
     }
     if (!empty())
     {
-        msg::dbg(_("Exception: %s"), _str.c_str());
+        msg::dbg_txt(_("Exception: %s"), _str.c_str());
     }
 }
 
@@ -103,7 +101,7 @@ exc::exc(const std::exception &e) throw ()
     }
     if (!empty())
     {
-        msg::dbg(_("Exception: %s"), _str.c_str());
+        msg::dbg_txt(_("Exception: %s"), _str.c_str());
     }
 }
 
