@@ -1,10 +1,11 @@
 /*
  * This file is part of bino, a 3D video player.
  *
- * Copyright (C) 2010, 2011, 2012
+ * Copyright (C) 2010, 2011, 2012, 2013
  * Martin Lambers <marlam@marlam.de>
  * Joe <cuchac@email.cz>
  * Binocle <http://binocle.com> (author: Olivier Letz <oletz@binocle.com>)
+ * Frédéric Bour <frederic.bour@lakaban.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -135,6 +136,7 @@ public:
         set_stereo_layout,              // video_frame::stereo_layout
         set_stereo_layout_swap,         // bool
         set_crop_aspect_ratio,          // float
+        set_source_aspect_ratio,        // float
         set_parallax,                   // float (absolute value)
         adjust_parallax,                // float (relative adjustment)
         set_ghostbust,                  // float (absolute value)
@@ -254,6 +256,7 @@ public:
         stereo_layout,
         stereo_layout_swap,
         crop_aspect_ratio,
+        source_aspect_ratio,
         parallax,
         ghostbust,
         subtitle_parallax,
