@@ -38,9 +38,6 @@ private:
     int _socket;
     struct lirc_config *_config;
 
-    // Helper function to read a command from a string
-    bool get_command(const std::string &s, command &c);
-
 public:
     lircclient(const std::string &client_name, const std::vector<std::string> &conf_files);
     ~lircclient();
