@@ -1,7 +1,7 @@
 /*
  * This file is part of bino, a 3D video player.
  *
- * Copyright (C) 2010, 2011, 2012
+ * Copyright (C) 2010, 2011, 2012, 2013, 2014
  * Martin Lambers <marlam@marlam.de>
  * Stefan Eilemann <eile@eyescale.ch>
  *
@@ -22,8 +22,10 @@
 #include "config.h"
 
 #include <sstream>
+#include <algorithm>
 #include <cmath>
 #include <cstdlib>
+#include <unistd.h>     // for usleep()
 
 #include <eq/eq.h>
 
@@ -228,51 +230,6 @@ public:
     }
 };
 
-/*
- * Define errors produced by player.
- */
-
-enum Error
-{
-    ERROR_MAP_INITDATA_FAILED = eq::ERROR_CUSTOM,
-    ERROR_MAP_FRAMEDATA_FAILED,
-    ERROR_PLAYER_INIT_FAILED,
-    ERROR_OPENGL_2_1_NEEDED
-};
-
-struct ErrorData
-{
-    const uint32_t code;
-    const std::string text;
-};
-
-static ErrorData errors[] =
-{
-    { ERROR_MAP_FRAMEDATA_FAILED, _("Init data mapping failed.") },
-    { ERROR_MAP_INITDATA_FAILED, _("Frame data mapping failed.") },
-    { ERROR_PLAYER_INIT_FAILED, _("Video player initialization failed.") },
-    { ERROR_OPENGL_2_1_NEEDED, _("Need at least OpenGL 2.1.") },
-    { 0, "" } // last!
-};
-
-static void initErrors()
-{
-    co::base::ErrorRegistry &registry = co::base::Global::getErrorRegistry();
-    for (size_t i = 0; errors[i].code != 0; i++)
-    {
-        registry.setString(errors[i].code, errors[i].text);
-    }
-}
-
-static void exitErrors()
-{
-    co::base::ErrorRegistry &registry = co::base::Global::getErrorRegistry();
-    for (size_t i = 0; errors[i].code != 0; i++)
-    {
-        registry.eraseString(errors[i].code);
-    }
-}
-
 /*
  * eq_init_data
  */
@@ -699,7 +656,7 @@ private:
                 eq::Vector3f w = u.cross(v);
                 w.normalize();
 
-                const eq::Vector3f dot = w.dot(eq::Vector3f::FORWARD);
+                const eq::Vector3f dot(w.dot(eq::Vector3f::FORWARD));
                 const float val = dot.squared_length();
                 if (val < angle) // facing more away then previous segment
                 {
@@ -712,12 +669,12 @@ private:
                 wall.apply(vp);
 
                 const eq::Vector3f topRight = wall.topLeft + wall.bottomRight - wall.bottomLeft;
-                float yMin = EQ_MIN(wall.bottomLeft.y(), wall.bottomRight.y());
-                float yMax = EQ_MAX(wall.bottomLeft.y(), wall.bottomRight.y());
-                yMin = EQ_MIN(yMin, wall.topLeft.y());
-                yMax = EQ_MAX(yMax, wall.topLeft.y());
-                yMin = EQ_MIN(yMin, topRight.y());
-                yMax = EQ_MAX(yMax, topRight.y());
+                float yMin = std::min(wall.bottomLeft.y(), wall.bottomRight.y());
+                float yMax = std::max(wall.bottomLeft.y(), wall.bottomRight.y());
+                yMin = std::min(yMin, wall.topLeft.y());
+                yMax = std::max(yMax, wall.topLeft.y());
+                yMin = std::min(yMin, topRight.y());
+                yMax = std::max(yMax, topRight.y());
 
                 const float h = yMax - yMin;
                 const eq::Vector3f center = (wall.bottomRight + wall.topLeft) * 0.5f;
@@ -776,13 +733,13 @@ protected:
         eq_config *config = static_cast<eq_config *>(getConfig());
         if (!config->mapObject(&init_data, init_id))
         {
-            setError(ERROR_MAP_INITDATA_FAILED);
+            msg::err(_("Init data mapping failed."));
             return false;
         }
         // Map our FrameData instance to the master instance
         if (!config->mapObject(&frame_data, init_data.frame_data_id))
         {
-            setError(ERROR_MAP_FRAMEDATA_FAILED);
+            msg::err(_("Frame data mapping failed."));
             return false;
         }
 
@@ -795,7 +752,7 @@ protected:
                     init_data.params.swap_interval());
             if (!_player.init(init_data.input))
             {
-                setError(ERROR_PLAYER_INIT_FAILED);
+                msg::err(_("Video player initialization failed."));
                 return false;
             }
         }
@@ -911,7 +868,6 @@ protected:
                     "GL_VERSION_2_1 GL_EXT_framebuffer_object"))
         {
             msg::err(_("This OpenGL implementation does not support OpenGL 2.1 and framebuffer objects."));
-            setError(ERROR_OPENGL_2_1_NEEDED);
             return false;
         }
 
@@ -1086,7 +1042,6 @@ player_equalizer::player_equalizer(int *argc, char *argv[], bool flat_screen) :
     assert(!global_player_equalizer);
     global_player_equalizer = this;
     /* Initialize Equalizer */
-    initErrors();
     _node_factory = new eq_node_factory;
     if (!eq::init(*argc, argv, _node_factory))
     {
@@ -1106,7 +1061,6 @@ player_equalizer::~player_equalizer()
 {
     eq::releaseConfig(_config);
     eq::exit();
-    exitErrors();
     delete _node_factory;
     global_player_equalizer = NULL;
 }
