@@ -88,6 +88,7 @@ private:
     subtitle_updater *_subtitle_updater;        // the subtitle updater thread
 #if HAVE_LIBXNVCTRL
     CNvSDIout *_nv_sdi_output;          // access the nvidia quadro sdi output card
+    int64_t _last_nv_sdi_displayed_frameno;
 #endif // HAVE_LIBXNVCTRL
 
     // GL Helper functions
@@ -172,7 +173,7 @@ protected:
     void display_current_frame(int64_t display_frameno = 0)
     {
         display_current_frame(display_frameno, false, false, -1.0f, -1.0f, 2.0f, 2.0f,
-                _viewport, _tex_coords, video_display_width(), video_display_height(),
+                _viewport, _tex_coords, full_display_width(), full_display_height(),
                 dispatch::parameters().stereo_mode());
     }
 
